"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const time_1 = require("./time");
const SECOND_MS = 1000;
const MINUTE_MS = 60 * SECOND_MS;
const HOUR_MS = 60 * MINUTE_MS;
const DAY_MS = 24 * HOUR_MS;
it('relative time, many permutations, compact', () => {
    const testDataTable = [
        {
            args: [0, { precision: 1 }],
            expected: '<1s'
        },
        {
            args: [SECOND_MS, { precision: 1 }],
            expected: '1s'
        },
        {
            args: [MINUTE_MS, { precision: 1 }],
            expected: '1m'
        },
        {
            args: [HOUR_MS, { precision: 1 }],
            expected: '1h'
        },
        {
            args: [DAY_MS, { precision: 1 }],
            expected: '1d'
        },
        {
            args: [0, { precision: 1, format: 'short' }],
            expected: '< 1 sec'
        },
        {
            args: [SECOND_MS, { precision: 1, format: 'short' }],
            expected: '1 sec'
        },
        {
            args: [MINUTE_MS, { precision: 1, format: 'short' }],
            expected: '1 min'
        },
        {
            args: [HOUR_MS, { precision: 1, format: 'short' }],
            expected: '1 hr'
        },
        {
            args: [DAY_MS, { precision: 1, format: 'short' }],
            expected: '1 day'
        },
        {
            args: [0, { precision: 1, format: 'full' }],
            expected: '< 1 second'
        },
        {
            args: [SECOND_MS, { precision: 1, format: 'full' }],
            expected: '1 second'
        },
        {
            args: [MINUTE_MS, { precision: 1, format: 'full' }],
            expected: '1 minute'
        },
        {
            args: [HOUR_MS, { precision: 1, format: 'full' }],
            expected: '1 hour'
        },
        {
            args: [DAY_MS, { precision: 1, format: 'full' }],
            expected: '1 day'
        }
    ];
    testDataTable.forEach((testData) => {
        const result = time_1.niceDuration.apply(null, testData.args);
        expect(result).toEqual(testData.expected);
    });
});
it('renders a duration for 0', () => {
    const duration = 0;
    const result = time_1.niceDuration(duration);
    expect(result).toEqual('<1s');
});
it('renders a duration for 1 second', () => {
    const duration = 1000;
    const result = time_1.niceDuration(duration);
    expect(result).toEqual('1s');
});
it('renders a duration for 1 minute', () => {
    const duration = 60000;
    const result = time_1.niceDuration(duration, { precision: 1 });
    expect(result).toEqual('1m');
});
it('renders a duration for 1 hour, minimal precision', () => {
    const duration = 3600000;
    const result = time_1.niceDuration(duration, { precision: 1 });
    expect(result).toEqual('1h');
});
it('renders a duration for 1 hour, full precision', () => {
    const duration = 3600000;
    const result = time_1.niceDuration(duration);
    expect(result).toEqual('1h 0m 0s');
});
it('renders a duration for 1 day, minimal precision', () => {
    const duration = 24 * 3600000;
    const result = time_1.niceDuration(duration, { precision: 1 });
    expect(result).toEqual('1d');
});
it('renders an relative time for now', () => {
    const refDate = new Date();
    const nowDate = refDate;
    const result = time_1.niceRelativeTime(refDate, { now: nowDate });
    expect(result).toEqual('now');
});
it('renders an relative time for 1 second from now', () => {
    const refDate = new Date(Date.now() + 1000);
    const result = time_1.niceRelativeTime(refDate, { format: 'full' });
    expect(result).toEqual('in 1 second');
});
it('renders an relative time for 2 seconds from now', () => {
    const refDate = new Date(Date.now() + 2000);
    const result = time_1.niceRelativeTime(refDate, { format: 'full' });
    expect(result).toEqual('in 2 seconds');
});
it('renders an relative time for 2 seconds from now, compact', () => {
    const refDate = new Date(Date.now() + 2000);
    const result = time_1.niceRelativeTime(refDate, { format: 'compact' });
    expect(result).toEqual('in 2s');
});
it('renders an relative time for 1 second ago', () => {
    const refDate = new Date(Date.now() - 1000);
    const result = time_1.niceRelativeTime(refDate, { format: 'full' });
    expect(result).toEqual('1 second ago');
});
it('renders an relative time for 2 second ago', () => {
    const refDate = new Date(Date.now() - 2000);
    const result = time_1.niceRelativeTime(refDate, { format: 'full' });
    expect(result).toEqual('2 seconds ago');
});
it('renders an relative time for 1 minute ago', () => {
    const refDate = new Date(Date.now() - 60000);
    const result = time_1.niceRelativeTime(refDate, { format: 'full' });
    expect(result).toEqual('1 minute ago');
});
it('renders an relative time for 1 hour ago', () => {
    const refDate = new Date(Date.now() - 3600000);
    const result = time_1.niceRelativeTime(refDate, { format: 'full' });
    expect(result).toEqual('1 hour ago');
});
it('renders many conditions, non-compact', () => {
    const now = Date.now();
    const testDataTable = [
        {
            args: [new Date(now - SECOND_MS), { format: 'full' }],
            expected: '1 second ago'
        },
        {
            args: [new Date(now - 2 * SECOND_MS), { format: 'full' }],
            expected: '2 seconds ago'
        },
        {
            args: [new Date(now - MINUTE_MS), { format: 'full' }],
            expected: '1 minute ago'
        },
        {
            args: [new Date(now - 2 * MINUTE_MS), { format: 'full' }],
            expected: '2 minutes ago'
        },
        {
            args: [new Date(now - HOUR_MS), { format: 'full' }],
            expected: '1 hour ago'
        },
        {
            args: [new Date(now - 2 * HOUR_MS), { format: 'full' }],
            expected: '2 hours ago'
        },
        {
            args: [new Date(now - DAY_MS), { format: 'full' }],
            expected: '1 day ago'
        },
        {
            args: [new Date(now - 2 * DAY_MS), { format: 'full' }],
            expected: '2 days ago'
        },
        {
            args: [new Date(now - SECOND_MS), { format: 'compact' }],
            expected: '1s ago'
        },
        {
            args: [new Date(now - 2 * SECOND_MS), { format: 'compact' }],
            expected: '2s ago'
        },
        {
            args: [new Date(now - MINUTE_MS), { format: 'compact' }],
            expected: '1m ago'
        },
        {
            args: [new Date(now - 2 * MINUTE_MS), { format: 'compact' }],
            expected: '2m ago'
        },
        {
            args: [new Date(now - HOUR_MS), { format: 'compact' }],
            expected: '1h ago'
        },
        {
            args: [new Date(now - 2 * HOUR_MS), { format: 'compact' }],
            expected: '2h ago'
        },
        {
            args: [new Date(now - DAY_MS), { format: 'compact' }],
            expected: '1d ago'
        },
        {
            args: [new Date(now - 2 * DAY_MS), { format: 'compact' }],
            expected: '2d ago'
        },
        {
            args: [new Date(now + SECOND_MS), { format: 'full' }],
            expected: 'in 1 second'
        },
        {
            args: [new Date(now + 2 * SECOND_MS), { format: 'full' }],
            expected: 'in 2 seconds'
        },
        {
            args: [new Date(now + MINUTE_MS), { format: 'full' }],
            expected: 'in 1 minute'
        },
        {
            args: [new Date(now + 2 * MINUTE_MS), { format: 'full' }],
            expected: 'in 2 minutes'
        },
        {
            args: [new Date(now + HOUR_MS), { format: 'full' }],
            expected: 'in 1 hour'
        },
        {
            args: [new Date(now + 2 * HOUR_MS), { format: 'full' }],
            expected: 'in 2 hours'
        },
        {
            args: [new Date(now + DAY_MS), { format: 'full' }],
            expected: 'in 1 day'
        },
        {
            args: [new Date(now + 2 * DAY_MS), { format: 'full' }],
            expected: 'in 2 days'
        }
    ];
    testDataTable.forEach((testData) => {
        const result = time_1.niceRelativeTime.apply(null, testData.args);
        expect(result).toEqual(testData.expected);
    });
});
it('renders an relative time at the limit', () => {
    const refDate = new Date(Date.now() + 30 * DAY_MS);
    const result = time_1.niceRelativeTime(refDate);
    expect(result).toEqual('in 30d');
});
it('renders an relative time beyond the default limit', () => {
    const nowDate = new Date('2019-01-01T00:00:00');
    const refDate = new Date(nowDate.getTime() + 1 + 90 * DAY_MS);
    const result = time_1.niceRelativeTime(refDate, { format: 'compact', now: nowDate });
    const expected = Intl.DateTimeFormat('en-US', {
        month: 'short',
        day: 'numeric'
    }).format(refDate);
    expect(result).toEqual(expected);
});
it('renders an relative time at the limit, custom time', () => {
    const nowDate = new Date('2019-01-01T00:00:00');
    const refDate = new Date(nowDate.getTime() + 30 * DAY_MS);
    const result = time_1.niceRelativeTime(refDate, {
        format: 'compact',
        now: nowDate,
        absoluteAfter: 30
    });
    expect(result).toEqual('in 30d');
});
it('renders an relative time beyond the limit, custom time', () => {
    const nowDate = new Date('2019-01-01T00:00:00');
    const refDate = new Date(nowDate.getTime() + 1 + 30 * DAY_MS);
    const result = time_1.niceRelativeTime(refDate, {
        format: 'compact',
        now: nowDate,
        absoluteAfter: 30
    });
    const expected = Intl.DateTimeFormat('en-US', {
        month: 'short',
        day: 'numeric'
    }).format(refDate);
    expect(result).toEqual(expected);
});
it('renders a nice elapsed time, happy story', () => {
    const testData = [
        {
            input: [0, {}],
            output: {
                label: '<1s',
                value: []
            }
        },
        {
            input: [50, {}],
            output: {
                label: '<1s',
                value: []
            }
        },
        {
            input: [1000, {}],
            output: {
                label: '1s',
                value: [
                    {
                        label: 's',
                        value: 1
                    }
                ]
            }
        },
        {
            input: [1 * MINUTE_MS, {}],
            output: {
                label: '1m 0s',
                value: [
                    {
                        label: 'm',
                        value: 1
                    },
                    {
                        label: 's',
                        value: 0
                    }
                ]
            }
        },
        {
            input: [1 * MINUTE_MS + 33 * SECOND_MS, {}],
            output: {
                label: '1m 33s',
                value: [
                    {
                        label: 'm',
                        value: 1
                    },
                    {
                        label: 's',
                        value: 33
                    }
                ]
            }
        },
        {
            input: [10 * DAY_MS, {}],
            output: {
                label: '10d 0h 0m 0s',
                value: [
                    {
                        label: 'd',
                        value: 10
                    },
                    {
                        label: 'h',
                        value: 0
                    },
                    {
                        label: 'm',
                        value: 0
                    },
                    {
                        label: 's',
                        value: 0
                    }
                ]
            }
        },
        {
            input: [60 * DAY_MS, {}],
            output: {
                label: '60d 0h 0m 0s',
                value: [
                    {
                        label: 'd',
                        value: 60
                    },
                    {
                        label: 'h',
                        value: 0
                    },
                    {
                        label: 'm',
                        value: 0
                    },
                    {
                        label: 's',
                        value: 0
                    }
                ]
            }
        },
        {
            input: [90 * DAY_MS, {}],
            output: {
                label: '90d 0h 0m 0s',
                value: [
                    {
                        label: 'd',
                        value: 90
                    },
                    {
                        label: 'h',
                        value: 0
                    },
                    {
                        label: 'm',
                        value: 0
                    },
                    {
                        label: 's',
                        value: 0
                    }
                ]
            }
        }
    ];
    testData.forEach((datum) => {
        const result = time_1.niceElapsed.apply(null, datum.input);
        expect(result).toBeInstanceOf(Object);
        expect(result).toEqual(datum.output);
    });
});
//# sourceMappingURL=time.test.js.map